Struct soup_sys::SoupCacheability [−]
#[repr(C)]pub struct SoupCacheability { /* fields omitted */ }
Methods
impl SoupCacheability
impl SoupCacheabilitypub const CACHEABLE: SoupCacheability
CACHEABLE: SoupCacheability = SoupCacheability{bits: 1,}
pub const UNCACHEABLE: SoupCacheability
UNCACHEABLE: SoupCacheability = SoupCacheability{bits: 2,}
pub const INVALIDATES: SoupCacheability
INVALIDATES: SoupCacheability = SoupCacheability{bits: 4,}
pub const VALIDATES: SoupCacheability
VALIDATES: SoupCacheability = SoupCacheability{bits: 8,}
pub fn empty() -> SoupCacheability
pub fn empty() -> SoupCacheabilityReturns an empty set of flags.
pub fn all() -> SoupCacheability
pub fn all() -> SoupCacheabilityReturns the set containing all flags.
pub fn bits(&self) -> c_uint
pub fn bits(&self) -> c_uintReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_uint) -> Option<SoupCacheability>
pub fn from_bits(bits: c_uint) -> Option<SoupCacheability>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_uint) -> SoupCacheability
pub fn from_bits_truncate(bits: c_uint) -> SoupCacheabilityConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: SoupCacheability) -> bool
pub fn intersects(&self, other: SoupCacheability) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: SoupCacheability) -> bool
pub fn contains(&self, other: SoupCacheability) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: SoupCacheability)
pub fn insert(&mut self, other: SoupCacheability)Inserts the specified flags in-place.
pub fn remove(&mut self, other: SoupCacheability)
pub fn remove(&mut self, other: SoupCacheability)Removes the specified flags in-place.
pub fn toggle(&mut self, other: SoupCacheability)
pub fn toggle(&mut self, other: SoupCacheability)Toggles the specified flags in-place.
pub fn set(&mut self, other: SoupCacheability, value: bool)
pub fn set(&mut self, other: SoupCacheability, value: bool)Inserts or removes the specified flags depending on the passed value.