Struct soup_sys::SoupExpectation [−]
#[repr(C)]pub struct SoupExpectation { /* fields omitted */ }
Methods
impl SoupExpectation
impl SoupExpectationpub const UNRECOGNIZED: SoupExpectation
UNRECOGNIZED: SoupExpectation = SoupExpectation{bits: 1,}
pub const CONTINUE: SoupExpectation
CONTINUE: SoupExpectation = SoupExpectation{bits: 2,}
pub fn empty() -> SoupExpectation
pub fn empty() -> SoupExpectationReturns an empty set of flags.
pub fn all() -> SoupExpectation
pub fn all() -> SoupExpectationReturns the set containing all flags.
pub fn bits(&self) -> c_uint
pub fn bits(&self) -> c_uintReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_uint) -> Option<SoupExpectation>
pub fn from_bits(bits: c_uint) -> Option<SoupExpectation>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_uint) -> SoupExpectation
pub fn from_bits_truncate(bits: c_uint) -> SoupExpectationConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: SoupExpectation) -> bool
pub fn intersects(&self, other: SoupExpectation) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: SoupExpectation) -> bool
pub fn contains(&self, other: SoupExpectation) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: SoupExpectation)
pub fn insert(&mut self, other: SoupExpectation)Inserts the specified flags in-place.
pub fn remove(&mut self, other: SoupExpectation)
pub fn remove(&mut self, other: SoupExpectation)Removes the specified flags in-place.
pub fn toggle(&mut self, other: SoupExpectation)
pub fn toggle(&mut self, other: SoupExpectation)Toggles the specified flags in-place.
pub fn set(&mut self, other: SoupExpectation, value: bool)
pub fn set(&mut self, other: SoupExpectation, value: bool)Inserts or removes the specified flags depending on the passed value.