Struct soup_sys::SoupMessageFlags [−]
#[repr(C)]pub struct SoupMessageFlags { /* fields omitted */ }
Methods
impl SoupMessageFlags
impl SoupMessageFlagspub const NO_REDIRECT: SoupMessageFlags
NO_REDIRECT: SoupMessageFlags = SoupMessageFlags{bits: 2,}
pub const CAN_REBUILD: SoupMessageFlags
CAN_REBUILD: SoupMessageFlags = SoupMessageFlags{bits: 4,}
pub const OVERWRITE_CHUNKS: SoupMessageFlags
OVERWRITE_CHUNKS: SoupMessageFlags = SoupMessageFlags{bits: 8,}
pub const CONTENT_DECODED: SoupMessageFlags
CONTENT_DECODED: SoupMessageFlags = SoupMessageFlags{bits: 16,}
pub const CERTIFICATE_TRUSTED: SoupMessageFlags
CERTIFICATE_TRUSTED: SoupMessageFlags = SoupMessageFlags{bits: 32,}
pub const NEW_CONNECTION: SoupMessageFlags
NEW_CONNECTION: SoupMessageFlags = SoupMessageFlags{bits: 64,}
pub const IDEMPOTENT: SoupMessageFlags
IDEMPOTENT: SoupMessageFlags = SoupMessageFlags{bits: 128,}
pub const IGNORE_CONNECTION_LIMITS: SoupMessageFlags
IGNORE_CONNECTION_LIMITS: SoupMessageFlags = SoupMessageFlags{bits: 256,}
pub fn empty() -> SoupMessageFlags
pub fn empty() -> SoupMessageFlagsReturns an empty set of flags.
pub fn all() -> SoupMessageFlags
pub fn all() -> SoupMessageFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_uint
pub fn bits(&self) -> c_uintReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_uint) -> Option<SoupMessageFlags>
pub fn from_bits(bits: c_uint) -> Option<SoupMessageFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_uint) -> SoupMessageFlags
pub fn from_bits_truncate(bits: c_uint) -> SoupMessageFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: SoupMessageFlags) -> bool
pub fn intersects(&self, other: SoupMessageFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: SoupMessageFlags) -> bool
pub fn contains(&self, other: SoupMessageFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: SoupMessageFlags)
pub fn insert(&mut self, other: SoupMessageFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: SoupMessageFlags)
pub fn remove(&mut self, other: SoupMessageFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: SoupMessageFlags)
pub fn toggle(&mut self, other: SoupMessageFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: SoupMessageFlags, value: bool)
pub fn set(&mut self, other: SoupMessageFlags, value: bool)Inserts or removes the specified flags depending on the passed value.